@@ -1,9 +1,11 @@
 import re
+from pathlib import Path
 
-import alabaster
 from pkg_resources import get_distribution
 from sphinx import addnodes
 
+import ablog
+
 ablog_builder = "dirhtml"
 ablog_website = "_website"
 extensions = [
@@ -14,24 +16,17 @@ extensions = [
     "sphinx.ext.ifconfig",
     "sphinx.ext.extlinks",
     "sphinx_automodapi.automodapi",
+    "ablog",
     "alabaster",
     "nbsphinx",
     "myst_parser",
-    "ablog",
 ]
 
-# PROJECT
 versionmod = get_distribution("ablog")
-myst_update_mathjax = False
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-# The short X.Y version.
 version = ".".join(versionmod.version.split(".")[:3])
-# The full version, including alpha/beta/rc tags.
 release = versionmod.version.split("+")[0]
-# Is this version a development release
 is_development = ".dev" in release
+
 project = "ABlog"
 copyright = "2014-2022, ABlog Team"
 master_doc = "index"
@@ -39,22 +34,19 @@ source_suffix = {
     ".rst": "restructuredtext",
     ".md": "markdown",
 }
-exclude_patterns = ["_build"]
+exclude_patterns = ["_build", "docs/manual/.ipynb_checkpoints"]
 
-# HTML OUTPUT
 html_title = "ABlog"
-html_static_path = ["_static"]
 html_use_index = True
 html_domain_indices = False
 html_show_sourcelink = True
 html_favicon = "_static/ablog.ico"
 
-# ABLOG
 blog_title = "ABlog"
-blog_baseurl = "https://ablog.readthedocs.org/"
+blog_baseurl = "https://ablog.readthedocs.io/"
 blog_locations = {
     "Pittsburgh": ("Pittsburgh, PA", "https://en.wikipedia.org/wiki/Pittsburgh"),
-    "SF": ("San Francisco, CA", "https://en.wikipedia.org/wiki/San_Francisco"),
+    "San Fran": ("San Francisco, CA", "https://en.wikipedia.org/wiki/San_Francisco"),
     "Denizli": ("Denizli, Turkey", "https://en.wikipedia.org/wiki/Denizli"),
 }
 blog_languages = {
@@ -71,42 +63,34 @@ blog_authors = {
 }
 blog_feed_archives = True
 blog_feed_fulltext = True
-blog_feed_length = None
 blog_feed_templates = {
-    # Use defaults, no templates
     "atom": {
-        # Format tags as hashtags and append to the content
-        "content": "{{ title }}{% for tag in post.tags %}"
-        " #{{ tag.name|trim()|replace(' ', '') }}"
-        "{% endfor %}",
+        "content": "{{ title }}{% for tag in post.tags %}" " #{{ tag.name|trim()|replace(' ', '') }}" "{% endfor %}",
     },
-    # Create content text suitable posting to micro-bogging
     "social": {
-        # Format tags as hashtags and append to the content
-        "content": "{{ title }}{% for tag in post.tags %}"
-        " #{{ tag.name|trim()|replace(' ', '') }}"
-        "{% endfor %}",
+        "content": "{{ title }}{% for tag in post.tags %}" " #{{ tag.name|trim()|replace(' ', '') }}" "{% endfor %}",
     },
 }
 disqus_shortname = "https-ablog-readthedocs-io"
 disqus_pages = True
 fontawesome_link_cdn = "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.1.1/css/all.min.css"
 
-# THEME
 html_style = "alabaster.css"
 html_theme = "alabaster"
 html_sidebars = {
     "**": [
         "about.html",
-        "postcard.html",
-        "recentposts.html",
-        "tagcloud.html",
-        "categories.html",
-        "archives.html",
+        "ablog/postcard.html",
+        "ablog/recentposts.html",
+        "ablog/tagcloud.html",
+        "ablog/categories.html",
+        "ablog/archives.html",
+        "ablog/authors.html",
+        "ablog/languages.html",
+        "ablog/locations.html",
         "searchbox.html",
     ]
 }
-html_theme_path = [alabaster.get_path()]
 html_theme_options = {
     "travis_button": False,
     "github_user": "sunpy",
@@ -115,7 +99,6 @@ html_theme_options = {
     "logo": "ablog.png",
 }
 
-# SPHINX
 intersphinx_mapping = {
     "python": ("https://docs.python.org/", None),
     "sphinx": ("https://www.sphinx-doc.org/en/master/", None),
@@ -125,7 +108,6 @@ extlinks = {
     "issue": ("https://github.com/sunpy/ablog/issues/%s", "issue %s"),
     "pull": ("https://github.com/sunpy/ablog/pull/%s", "pull request %s"),
 }
-exclude_patterns = ["docs/manual/.ipynb_checkpoints/*"]
 rst_epilog = """
 .. _Sphinx: http://sphinx-doc.org/
 .. _Python: https://python.org
@@ -135,6 +117,15 @@ rst_epilog = """
 .. _Read The Docs: https://readthedocs.org/
 .. _Alabaster: https://github.com/bitprophet/alabaster
 """
+locale_dirs = [str(Path(ablog.__file__).parent / Path("locales"))]
+nitpicky = True
+nitpick_ignore = []
+for line in open("nitpick-exceptions"):
+    if line.strip() == "" or line.startswith("#"):
+        continue
+    dtype, target = line.split(None, 1)
+    target = target.strip()
+    nitpick_ignore.append((dtype, target))
 
 
 def parse_event(env, sig, signode):
